Struct sql_abstractor::Postgres

source ·
pub struct Postgres { /* private fields */ }
Postgress implementation.

It’s a wrapper around sqlx::postgres

Examples

It implemeents orchestrator memory abstraction, that means that could be used as:

use sql_abstractor::Postgres;
use orchestrator::prelude::*;
 
GenerateState!(ExerciseResult, DummyExercise);
let m = Box::new(
    Postgres::clean_init("postgresql://postgres:test@localhost:5432/thesis")
    .await
    .unwrap(),
);
let mut o: Orchestrator<State> = Orchestrator::new(1, m);
o.run().await;

Implementations

source

impl Postgres

implement some initialization

source

pub async fn init(builder: &str) -> Result<Self, Error>

initialize connector It could be used multiple times without loosing any data.

This is the correct way to obtain Self

source

pub async fn clean_init(builder: &str) -> Result<Self, Error>

WARNING: THIS WILL ERASE ALL THE DATA CONTAINED IN THE DATABASE, AND THEN INIT